package com.ruoyi.model.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.model.domain.AppOrder;
import com.ruoyi.model.service.IAppOrderService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 订单Controller
 * 
 * @author ruoyi
 * @date 2025-03-08
 */
@RestController
@RequestMapping("/model/AppOrder")
public class AppOrderController extends BaseController
{
    @Autowired
    private IAppOrderService appOrderService;

    /**
     * 查询订单列表
     */
    @PreAuthorize("@ss.hasPermi('model:AppOrder:list')")
    @GetMapping("/list")
    public TableDataInfo list(AppOrder appOrder)
    {
        startPage();
        List<AppOrder> list = appOrderService.selectAppOrderList(appOrder);
        return getDataTable(list);
    }

    /**
     * 导出订单列表
     */
    @PreAuthorize("@ss.hasPermi('model:AppOrder:export')")
    @Log(title = "订单", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AppOrder appOrder) throws IOException {
        List<AppOrder> list = appOrderService.selectAppOrderList(appOrder);
        ExcelUtil<AppOrder> util = new ExcelUtil<AppOrder>(AppOrder.class);
        util.exportExcel(response, list, "订单数据");
    }

    /**
     * 获取订单详细信息
     */
    @PreAuthorize("@ss.hasPermi('model:AppOrder:query')")
    @GetMapping(value = "/{orderId}")
    public AjaxResult getInfo(@PathVariable("orderId") Long orderId)
    {
        return success(appOrderService.selectAppOrderByOrderId(orderId));
    }

    /**
     * 新增订单
     */
    @PreAuthorize("@ss.hasPermi('model:AppOrder:add')")
    @Log(title = "订单", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AppOrder appOrder)
    {
        return toAjax(appOrderService.insertAppOrder(appOrder));
    }

    /**
     * 修改订单
     */
    @PreAuthorize("@ss.hasPermi('model:AppOrder:edit')")
    @Log(title = "订单", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AppOrder appOrder)
    {
        return toAjax(appOrderService.updateAppOrder(appOrder));
    }

    /**
     * 删除订单
     */
    @PreAuthorize("@ss.hasPermi('model:AppOrder:remove')")
    @Log(title = "订单", businessType = BusinessType.DELETE)
	@DeleteMapping("/{orderIds}")
    public AjaxResult remove(@PathVariable Long[] orderIds)
    {
        return toAjax(appOrderService.deleteAppOrderByOrderIds(orderIds));
    }
}
